@@ -12,7 +12,7 @@
 #include <unistd.h>
 #include <string.h>
 
-#define INK_VERSION_STRING "ink v0.4.1"
+#define INK_VERSION_STRING "ink v0.5.0"
 
 void usage(void) {
   printf(
@@ -23,7 +23,10 @@ void usage(void) {
   printf("'ink -p parport -n 1' Query second parallel port printer\n");
   printf("'ink -p usb' Query first usb port printer\n");
   printf("'ink -p usb -n 1' Query second usb port printer\n");
-  printf("'ink -d /dev/usblp0' Query usb printer on device /dev/usblp0\n");
+  printf("'ink -p bjnp' Query first bjnp network printer\n");
+    printf("'ink -d /dev/usblp0' Query usb printer on device /dev/usblp0\n");
+  printf("'ink -b printer.my.domain' Query bjnp network printer on printer.my.domain\n");
+  printf("'ink -b 111.222.111.222' Query bjnp network printer on ip-address 111.222.111.222\n");
   printf("'ink -v' Show version information\n");
 }
 
@@ -83,7 +86,7 @@ int main(int argc, char *argv[]) {
   };
 
   strcat(headerline, INK_VERSION_STRING);
-  strcat(headerline, "  2007 Markus Heinz\n\n");
+  strcat(headerline, " (c) 2009 Markus Heinz\n\n");
 
   printf(headerline);
 
@@ -92,14 +95,16 @@ int main(int argc, char *argv[]) {
     return 1;
   }
 
-  while ((c = getopt(argc, argv, "p:n:d:v")) != -1) {
+  while ((c = getopt(argc, argv, "b:p:n:d:v")) != -1) {
     switch (c) {
     case 'p':
       if (strcmp(optarg, "parport") == 0) {
 	port = PARPORT;
       } else if (strcmp(optarg, "usb") == 0) {
 	port = USB;
-      } else {
+       } else if (strcmp(optarg, "bjnp") == 0) {
+        port = BJNP;
+     } else {
 	usage();
 	return 1;
       }
@@ -113,6 +118,15 @@ int main(int argc, char *argv[]) {
         return 1;
       }
       break;
+    case 'b':
+      if (optarg) {
+        devicefile = optarg;
+        port = CUSTOM_BJNP;
+      } else {
+        usage();
+        return 1;
+      }
+      break;
     case 'n':
       if (optarg) {
 	portnumber = atoi(optarg);
@@ -191,7 +205,13 @@ int main(int argc, char *argv[]) {
     case DEV_CUSTOM_USB_INACCESSIBLE:
       printf("Could not access custom usb device '%s'.\n", devicefile);
       break;
-    }
+    case BJNP_URI_INVALID:
+      printf("Printer URI is invalid: '%s'.\n", devicefile);
+      break;
+    case BJNP_INVALID_HOSTNAME:
+      printf("Could not open hostname: '%s'.\n", devicefile);
+      break;
+   }
     printf("Could not get ink level.\n");
     free(level);
     return 1;
